==> torcms-0.8.8.tar.gz: torcms-0.8.8/torcms/modules/modef.py <==
# -*- coding:utf-8 -*-
'''
定义模块的名称，作为调用的名称
'''

from torcms.modules import (base_modules, catalog_modules, category_modules,
                            info_modules, widget_modules)

core_modules = {
    'previous_post_link': base_modules.PreviousPostLink,
    'next_post_link': base_modules.NextPostLink,
    'the_category': base_modules.TheCategory,
    'list_categories': base_modules.ListCategories,
    'post_most_view': base_modules.PostMostView,
    'post_random': base_modules.PostRandom,
    'post_recent': base_modules.PostRecent,
    'post_labels': base_modules.PostLabels,
    'link_list': base_modules.LinkList,
    'post_recent_most_view': base_modules.PostRecentMostView,
    'post_cat_random': base_modules.PostCatRandom,
    'post_cat_recent': base_modules.PostCategoryRecent,
    'showout_recent': base_modules.ShowoutRecent,
    'generate_abstract': base_modules.GenerateAbstract,
    'site_url': base_modules.SiteUrl,
    'site_title': base_modules.SiteTitle,
    # 'generate_description': base_modules.GenerateDescription,
    'post_tags': base_modules.PostTags,
    'post_catalogs': base_modules.PostTags,
    'map_catalogs': base_modules.MapTags,
    'post_categories': base_modules.PostTags,
    'catalog_pager': base_modules.CategoryPager,
    'info_label_pager': base_modules.InfoLabelPager,
    'label_pager': base_modules.LabelPager,
    'tag_pager': base_modules.TagPager,
    'search_pager': base_modules.SearchPager,
    'collect_pager': base_modules.CollectPager,
    'log_pager': base_modules.LogPager,
    'log_pageview_pager': base_modules.LogPageviewPager,
    'catalog_of': base_modules.CategoryOf,
    'post_catalog_of': base_modules.PostCategoryOf,
    'show_page': base_modules.ShowPage,
    'collect': base_modules.Collect,
    'user_collect': base_modules.UserCollect,
    'entity_list': base_modules.EntityList,
    'entity_pager': base_modules.EntityPager,
    'entity_download_user': base_modules.Entity2UserPager,
    'entity_download_list': base_modules.Entity2Pager,
    'app_title': base_modules.AppTitle,
    'user_name_by_id': base_modules.UserName,
    'reply_post_by_id': base_modules.ReplyPostById,
    'category_by_slug': base_modules.CategoryBySlug,
    'admin_post_pager': base_modules.Admin_Post_pager,
    'admin_page_pager': base_modules.Admin_Page_pager,
    'admin_reply_pager': base_modules.Admin_reply_pager,
    'admin_user_pager': base_modules.Admin_user_pager,
    'admin_log_pager': base_modules.Admin_log_pager,
    'pageview_count': base_modules.LogPageviewCount,
    'info_nullify': base_modules.InfoNullify,
    'nullify_pager': base_modules.Nullify_pager,
    'comment_num': base_modules.Comment_num,
    'comment_pager': base_modules.Comment_pager,

    # widget
    'reply_panel': widget_modules.ReplyPanel,
    'baidu_share': widget_modules.BaiduShare,
    'widget_search': widget_modules.WidgetSearch,
    'widget_editor': widget_modules.WidgetEditor,
    'star_rating': widget_modules.StarRating,
    'use_f2e': widget_modules.UseF2E,
    'loginfo': widget_modules.UserinfoWidget,
    'upload_pic': widget_modules.UploadPicture,
    'upload_file': widget_modules.UploadFile,
    'nav_menu': widget_modules.Navigation_menu,

    # Infor
    'app_catalog_of': info_modules.InfoCategory,
    'parentname': info_modules.ParentName,
    'catname': info_modules.CatName,
    'BreadcrumbPublish': info_modules.BreadcrumbPublish,
    'rel_post2app': info_modules.RelPost2app,
    'rel_app2post': info_modules.RelApp2post,
    'app_random_choose': info_modules.InfoRandom,
    'app_tags': info_modules.InfoTags,
    'app_menu': info_modules.InfoMenu,
    'app_user_most': info_modules.InforUserMost,
    'app_recent_used': info_modules.InfoRecentUsed,
    'app_most_used': info_modules.InfoMostUsed,
    'label_count': info_modules.LabelCount,
    'info_count': info_modules.InfoCount,
    'recent_access': info_modules.RecentAccess,
    'relate_doc': info_modules.RelateDoc,

    # Category
    'category_menu': category_modules.CategoryMenu,
    'category_name': category_modules.CategoryName,
    'catalog_menu': catalog_modules.CatalogMenu,
    'catalog_list': catalog_modules.CatalogList,
    'secondary_category_menu': category_modules.SecondaryCategoryMenu,
    'secondary_category_list': category_modules.SecondaryCategoryList,
    # Comment
    'comment_list': widget_modules.CommentList,
    'replycnt': widget_modules.Replycnt,
    'user_profile_by_id': widget_modules.Userprofile,
    'post_state': widget_modules.State,
    'check_pager': widget_modules.Check_pager,
    'check_username_pager': widget_modules.Check_username_pager
}

==> torcms-0.8.10.tar.gz: torcms-0.8.10/torcms/modules/modef.py <==
# -*- coding:utf-8 -*-
'''
定义模块的名称，作为调用的名称
'''

from torcms.modules import (
    base_modules,
    catalog_modules,
    category_modules,
    info_modules,
    widget_modules,
)

core_modules = {
    'previous_post_link': base_modules.PreviousPostLink,
    'next_post_link': base_modules.NextPostLink,
    'the_category': base_modules.TheCategory,
    'list_categories': base_modules.ListCategories,
    'post_most_view': base_modules.PostMostView,
    'post_random': base_modules.PostRandom,
    'post_recent': base_modules.PostRecent,
    'post_labels': base_modules.PostLabels,
    'link_list': base_modules.LinkList,
    'post_recent_most_view': base_modules.PostRecentMostView,
    'post_cat_random': base_modules.PostCatRandom,
    'post_cat_recent': base_modules.PostCategoryRecent,
    'showout_recent': base_modules.ShowoutRecent,
    'generate_abstract': base_modules.GenerateAbstract,
    'site_url': base_modules.SiteUrl,
    'site_title': base_modules.SiteTitle,
    # 'generate_description': base_modules.GenerateDescription,
    'post_tags': base_modules.PostTags,
    'post_catalogs': base_modules.PostTags,
    'map_catalogs': base_modules.MapTags,
    'post_categories': base_modules.PostTags,
    'catalog_pager': base_modules.CategoryPager,
    'info_label_pager': base_modules.InfoLabelPager,
    'label_pager': base_modules.LabelPager,
    'tag_pager': base_modules.TagPager,
    'search_pager': base_modules.SearchPager,
    'collect_pager': base_modules.CollectPager,
    'log_pager': base_modules.LogPager,
    'log_pageview_pager': base_modules.LogPageviewPager,
    'catalog_of': base_modules.CategoryOf,
    'post_catalog_of': base_modules.PostCategoryOf,
    'show_page': base_modules.ShowPage,
    'collect': base_modules.Collect,
    'user_collect': base_modules.UserCollect,
    'entity_list': base_modules.EntityList,
    'entity_pager': base_modules.EntityPager,
    'entity_download_user': base_modules.Entity2UserPager,
    'entity_download_list': base_modules.Entity2Pager,
    'entity_download_count': base_modules.Entity2DownloadCount,
    'entity_get_post': base_modules.EntityGetPost,
    'app_title': base_modules.AppTitle,
    'user_name_by_id': base_modules.UserName,
    'reply_post_by_id': base_modules.ReplyPostById,
    'category_by_slug': base_modules.CategoryBySlug,
    'admin_post_pager': base_modules.Admin_Post_pager,
    'admin_page_pager': base_modules.Admin_Page_pager,
    'admin_reply_pager': base_modules.Admin_reply_pager,
    'reply_pager': base_modules.Reply_pager,
    'reply_user_pager': base_modules.Reply_user_pager,
    'admin_user_pager': base_modules.Admin_user_pager,
    'admin_log_pager': base_modules.Admin_log_pager,
    'pageview_count': base_modules.LogPageviewCount,
    'info_nullify': base_modules.InfoNullify,
    'nullify_pager': base_modules.Nullify_pager,
    'comment_num': base_modules.Comment_num,
    'comment_pager': base_modules.Comment_pager,
    # widget
    'reply_panel': widget_modules.ReplyPanel,
    'reply_panel_index': widget_modules.ReplyPanelIndex,
    'baidu_share': widget_modules.BaiduShare,
    'widget_search': widget_modules.WidgetSearch,
    'widget_editor': widget_modules.WidgetEditor,
    'star_rating': widget_modules.StarRating,
    'use_f2e': widget_modules.UseF2E,
    'loginfo': widget_modules.UserinfoWidget,
    'upload_pic': widget_modules.UploadPicture,
    'upload_file': widget_modules.UploadFile,
    'nav_menu': widget_modules.Navigation_menu,
    # Infor
    'app_catalog_of': info_modules.InfoCategory,
    'parentname': info_modules.ParentName,
    'catname': info_modules.CatName,
    'BreadcrumbPublish': info_modules.BreadcrumbPublish,
    'rel_post2app': info_modules.RelPost2app,
    'rel_app2post': info_modules.RelApp2post,
    'app_random_choose': info_modules.InfoRandom,
    'app_tags': info_modules.InfoTags,
    'app_menu': info_modules.InfoMenu,
    'app_user_most': info_modules.InforUserMost,
    'app_recent_used': info_modules.InfoRecentUsed,
    'app_most_used': info_modules.InfoMostUsed,
    'label_count': info_modules.LabelCount,
    'info_count': info_modules.InfoCount,
    'recent_access': info_modules.RecentAccess,
    'relate_doc': info_modules.RelateDoc,
    # Category
    'category_menu': category_modules.CategoryMenu,
    'category_name': category_modules.CategoryName,
    'catalog_menu': catalog_modules.CatalogMenu,
    'catalog_list': catalog_modules.CatalogList,
    'secondary_category_menu': category_modules.SecondaryCategoryMenu,
    'secondary_category_list': category_modules.SecondaryCategoryList,
    # Comment
    'comment_list': widget_modules.CommentList,
    'replycnt': widget_modules.Replycnt,
    'reply_count': widget_modules.Replycount,
    'reply_recent_cnt': widget_modules.ReplyRecentcnt,
    'user_profile_by_id': widget_modules.Userprofile,
    'post_state': widget_modules.State,
    'check_pager': widget_modules.Check_pager,
    'check_username_pager': widget_modules.Check_username_pager,
}
